SOQL
====

.. image:: https://travis-ci.org/plangrid/soql.svg?branch=master
   :target: https://travis-ci.org/plangrid/soql
   :alt: CI Status

.. image:: https://badge.fury.io/py/soql.svg
   :target: https://badge.fury.io/py/soql
   :alt: PyPI status

|

Models and query generator for Salesforce Object Query Language (SOQL)


Example
-------


Installation
------------

.. code-block::

   pip install soql


Documentation
-------------



Contributing
------------

There is still work to be done, and contributions are encouraged! Check out the `contribution guide <CONTRIBUTING.rst>`_ for more information.
